# The thermal decomposition of CL-20 (C<sub>6</sub>H<sub>6</sub>N<sub>12</sub>O<sub>12</sub>)

This tutorial is proposed to develop a Deep Potential for the thermal decomposition of CL-20, perform MD simulations, and then use the ReacNetGenerator to analyze reactions.  

This tutorial introduces:

```{bibliography}
---
filter: False
---
Cao_PhysChemChemPhys_2022_v24_p11801
```

## DP-GEN workflow

In this study, a workflow was developed for making reference datasets with DP-GEN program. The details of each module in the workflow are given in {cite:t}`Cao_PhysChemChemPhys_2022_v24_p11801`.

You can install DP-GEN program with the tutorial in [DP-GEN](https://github.com/deepmodeling/dpgen).{cite:p}`Zhang_ComputPhysCommun_2020_v253_p107206`
In this example, the input files for DP-GEN program are provided [here](https://github.com/tongzhugroup/NNREAX/blob/cbb5cbf3eb3b89919ee555147427e071c012f37a/cl20/cl20_v1.yaml).

During the DP-GEN workflow, each iteration includes three steps: QM calculation, training of the NN PES, and reactive molecular dynamic simulations.

### QM calculation

CP2K package was used for DFT calculation, which can be obtained at [CP2k](https://github.com/cp2k/cp2k).{cite:p}`Kuhne_JChemPhys_2020_v152_p194103`
PBE-D3 method was employed in this example, because it is generally used for DFT calculation of energetic materials.

### Training of the NN PES

The DeepPot-SE (Deep Potential-Smooth Edition) model was used to train the NN potential by the DeePMD-kit program.
You can install DeePMD-kit program with the tutorial in [DeePMD-kit](https://github.com/deepmodeling/deepmd-kit).{cite:p}`Wang_ComputPhysCommun_2018_v228_p178`

### Reactive molecular dynamic simulations

After training, the well-behaved NN PESs can be used for running molecular dynamics simulation by LAMMPS interfaced with DeePMD-kit program.{cite:p}`Thompson_ComputPhysCommun_2022_v271_p108171`

## Analysis by ReacNetGenerator

DP-GEN software will produce a series of reactive simulation trajectory.
Here we take the final trajectory.
The trajectory of a single frame can be integrated into [the entire trajectory](https://github.com/tongzhugroup/TRAJREAX/blob/f10a5c2cab77d3f3b659d9dd08256ae7b27c2820/cl20/cl20.lammpstrj), and the format of trajectory here is `dump`. The reaction mechanism can be obtained by the following command:

```sh
reacnetgenerator -i cl20.lammpstrj -a H C N O --type dump --nohmm
```

The results can be viewed at <a href="/report.html?jdata=https://fastly.jsdelivr.net/gh/tongzhugroup/TRAJREAX@f10a5c2cab77d3f3b659d9dd08256ae7b27c2820/cl20/cl20.json&">this page</a>.
